@@ -35,7 +35,7 @@ class KeyboardBrightnessControl : public PowerDevil::Action
 
 public:
     explicit KeyboardBrightnessControl(QObject* parent);
-    virtual ~KeyboardBrightnessControl();
+    virtual ~KeyboardBrightnessControl() = default;
 
 protected:
     virtual void onProfileUnload();
@@ -57,25 +57,20 @@ public Q_SLOTS:
     void toggleKeyboardBacklight();
 
     int keyboardBrightness() const;
-    void setKeyboardBrightness(int percent);
-    void setKeyboardBrightnessSilent(int percent);
+    int keyboardBrightnessMax() const;
+    void setKeyboardBrightness(int value);
+    void setKeyboardBrightnessSilent(int value);
 
-    int keyboardBrightnessValue() const;
-    int keyboardBrightnessValueMax() const;
-    void setKeyboardBrightnessValue(int value);
-    void setKeyboardBrightnessValueSilent(int value);
-
-    int keyboardBrightnessStep() const;
-    int keyboardBrightnessStepMax() const;
-    void setKeyboardBrightnessStep(int step);
+    int keyboardBrightnessSteps() const;
 
 Q_SIGNALS:
-    void keyboardBrightnessChanged(int percent);
-    void keyboardBrightnessValueChanged(int value);
-    void keyboardBrightnessStepChanged(int step);
+    void keyboardBrightnessChanged(int value);
+    void keyboardBrightnessMaxChanged(int valueMax);
 
 private:
-    int m_defaultValue;
+    int keyboardBrightnessPercent() const;
+
+    int m_defaultValue = -1;
     QString m_lastProfile;
     QString m_currentProfile;
 };
